Installation
============

.. highlight:: bash

Penguins requires Python 3.7 or later. Other dependencies are:

* ``numpy`` v1.17.0+
* ``matplotlib``
* ``seaborn``

From PyPI
---------

Simply run::

   pip install penguins


From source
-----------

Clone the repository and install with ``pip``::

   git clone https://github.com/yongrenjie/penguins
   cd penguins
   pip install .
